==> kipi-plugins-trinity_3.5.13.2.orig.tar.xz: kipi-plugins-trinity-3.5.13.2/kipi-plugins/sendimages/plugin_sendimages.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2003-10-01
 * Description : a kipi plugin to e-mailing images
 *
 * Copyright (C) 2003-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef PLUGIN_SENDIMAGES_H
#define PLUGIN_SENDIMAGES_H

// KIPI includes

#include <libkipi/plugin.h>

class TQCustomEvent;

class KAction;
class KIPISendimagesPlugin::SendImages;

namespace KIPI
{
    class BatchProgressDialog;
}

class Plugin_SendImages : public KIPI::Plugin
{
Q_OBJECT
  TQ_OBJECT

public:

   Plugin_SendImages(TQObject *parent, const char* name, const TQStringList &args);
   ~Plugin_SendImages();
   
   virtual KIPI::Category category( KAction* action ) const;
   virtual void setup( TQWidget* );
  
public slots:

   void slotActivate();
   void slotCancel();
   void slotAcceptedConfigDlg();

private:

   void customEvent(TQCustomEvent *event);
   
private:

   int                               m_current;
   int                               m_total;

   KAction                          *m_action_sendimages;
   
   KIPI::BatchProgressDialog        *m_progressDlg;
   
   KIPISendimagesPlugin::SendImages *m_sendImagesOperation;
};

#endif // PLUGIN_SENDIMAGES_H

==> kipi-plugins-trinity-14.0.13.tar.xz: kipi-plugins-trinity-14.0.13/kipi-plugins/sendimages/plugin_sendimages.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2003-10-01
 * Description : a kipi plugin to e-mailing images
 *
 * Copyright (C) 2003-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef PLUGIN_SENDIMAGES_H
#define PLUGIN_SENDIMAGES_H

// KIPI includes

#include <libkipi/plugin.h>

class TQCustomEvent;

class TDEAction;
namespace KIPISendimagesPlugin {
    class SendImages;
}

namespace KIPI
{
    class BatchProgressDialog;
}

class Plugin_SendImages : public KIPI::Plugin
{
Q_OBJECT
  

public:

   Plugin_SendImages(TQObject *parent, const char* name, const TQStringList &args);
   ~Plugin_SendImages();
   
   virtual KIPI::Category category( TDEAction* action ) const;
   virtual void setup( TQWidget* );
  
public slots:

   void slotActivate();
   void slotCancel();
   void slotAcceptedConfigDlg();

private:

   void customEvent(TQCustomEvent *event);
   
private:

   int                               m_current;
   int                               m_total;

   TDEAction                          *m_action_sendimages;
   
   KIPI::BatchProgressDialog        *m_progressDlg;
   
   KIPISendimagesPlugin::SendImages *m_sendImagesOperation;
};

#endif // PLUGIN_SENDIMAGES_H
